# Changelog

## [V0.0."37.post1"](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0."37.post1") (2023-12-29)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.1.0a2...V0.0."37.post1")

## [V0.1.0a2](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.1.0a2) (2023-12-29)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.37...V0.1.0a2)

**Breaking changes:**

- 0.1.0 alpha 1 [\#204](https://github.com/OpenVoiceOS/ovos-utils/pull/204) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.37](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.37) (2023-12-28)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.37a4...V0.0.37)

## [V0.0.37a4](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.37a4) (2023-12-28)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.37a3...V0.0.37a4)

**Merged pull requests:**

- deprecate bus utils [\#207](https://github.com/OpenVoiceOS/ovos-utils/pull/207) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.37a3](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.37a3) (2023-12-28)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.37a2...V0.0.37a3)

**Closed issues:**

- decouple concerns from bus/workshop [\#205](https://github.com/OpenVoiceOS/ovos-utils/issues/205)

**Merged pull requests:**

- LAST ALPHA [\#206](https://github.com/OpenVoiceOS/ovos-utils/pull/206) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.37a2](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.37a2) (2023-12-18)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.37a1...V0.0.37a2)

**Fixed bugs:**

- update imports for py 3.10 compat [\#202](https://github.com/OpenVoiceOS/ovos-utils/pull/202) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.37a1](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.37a1) (2023-11-08)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.36...V0.0.37a1)

**Fixed bugs:**

- elevate sound media role [\#201](https://github.com/OpenVoiceOS/ovos-utils/pull/201) ([emphasize](https://github.com/emphasize))

## [V0.0.36](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.36) (2023-10-26)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.36a12...V0.0.36)

**Closed issues:**

- Import `EventSchedulerInterface` from ovos-bus-client [\#168](https://github.com/OpenVoiceOS/ovos-utils/issues/168)

## [V0.0.36a12](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.36a12) (2023-10-25)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.36a11...V0.0.36a12)

**Fixed bugs:**

- \[GUI\] `_pages2uri` reports page not found when omitting extension [\#194](https://github.com/OpenVoiceOS/ovos-utils/issues/194)

**Merged pull requests:**

- Remove error log for GUI resource resolution [\#198](https://github.com/OpenVoiceOS/ovos-utils/pull/198) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.36a11](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.36a11) (2023-10-25)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.36a10...V0.0.36a11)

**Merged pull requests:**

- deprecate the sound utils module [\#190](https://github.com/OpenVoiceOS/ovos-utils/pull/190) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.36a10](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.36a10) (2023-10-19)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.36a9...V0.0.36a10)

**Fixed bugs:**

- fix/scheduled\_event message.context [\#196](https://github.com/OpenVoiceOS/ovos-utils/pull/196) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.36a9](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.36a9) (2023-10-12)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.36a8...V0.0.36a9)

**Implemented enhancements:**

- update FakeBus to support session [\#195](https://github.com/OpenVoiceOS/ovos-utils/pull/195) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.36a8](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.36a8) (2023-09-26)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.36a7...V0.0.36a8)

**Implemented enhancements:**

- Support "logging" section to allow per-service log level changes [\#189](https://github.com/OpenVoiceOS/ovos-utils/pull/189) ([lbt](https://github.com/lbt))

## [V0.0.36a7](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.36a7) (2023-09-17)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.36a6...V0.0.36a7)

**Fixed bugs:**

- hotfix/gui\_sync [\#192](https://github.com/OpenVoiceOS/ovos-utils/pull/192) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.36a6](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.36a6) (2023-09-13)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.36a5...V0.0.36a6)

**Merged pull requests:**

- refactor/less\_gui\_spam [\#191](https://github.com/OpenVoiceOS/ovos-utils/pull/191) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.36a5](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.36a5) (2023-09-05)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.36a4...V0.0.36a5)

**Implemented enhancements:**

- Only scan for executables if a good one has not yet been found [\#187](https://github.com/OpenVoiceOS/ovos-utils/pull/187) ([lbt](https://github.com/lbt))

## [V0.0.36a4](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.36a4) (2023-09-05)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.36a3...V0.0.36a4)

**Implemented enhancements:**

- IntentServiceInterface Tests and Minor Fixes [\#186](https://github.com/OpenVoiceOS/ovos-utils/pull/186) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.36a3](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.36a3) (2023-08-17)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.36a2...V0.0.36a3)

**Fixed bugs:**

- remove \_HACK [\#184](https://github.com/OpenVoiceOS/ovos-utils/pull/184) ([JarbasAl](https://github.com/JarbasAl))

**Closed issues:**

- \_\_HACK\_preload in file\_utils.py causes circular import when launching ovos\_dinkum\_listener [\#183](https://github.com/OpenVoiceOS/ovos-utils/issues/183)

## [V0.0.36a2](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.36a2) (2023-08-07)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.36a1...V0.0.36a2)

**Fixed bugs:**

- HACK / speed up resolve\_ovos\_resource\_file [\#182](https://github.com/OpenVoiceOS/ovos-utils/pull/182) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.36a1](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.36a1) (2023-08-07)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.35...V0.0.36a1)

**Merged pull requests:**

- Update `events` module docs and default values [\#181](https://github.com/OpenVoiceOS/ovos-utils/pull/181) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.35](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.35) (2023-07-20)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.35a9...V0.0.35)

## [V0.0.35a9](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.35a9) (2023-07-19)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.35a8...V0.0.35a9)

**Implemented enhancements:**

- feat/threaded\_timeout\_util [\#169](https://github.com/OpenVoiceOS/ovos-utils/pull/169) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.35a8](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.35a8) (2023-07-13)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.35a7...V0.0.35a8)

**Fixed bugs:**

- fix ui directores [\#179](https://github.com/OpenVoiceOS/ovos-utils/pull/179) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.35a7](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.35a7) (2023-07-07)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.35a6...V0.0.35a7)

**Merged pull requests:**

- Volunteer GUI upload on init [\#178](https://github.com/OpenVoiceOS/ovos-utils/pull/178) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.35a6](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.35a6) (2023-07-06)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.35a5...V0.0.35a6)

**Merged pull requests:**

- Enable GUI module resource file resolution [\#177](https://github.com/OpenVoiceOS/ovos-utils/pull/177) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.35a5](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.35a5) (2023-07-04)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.35a4...V0.0.35a5)

**Fixed bugs:**

- Fix bug in `dev` branch with refactoring and added unit test [\#176](https://github.com/OpenVoiceOS/ovos-utils/pull/176) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.35a4](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.35a4) (2023-07-04)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.35a3...V0.0.35a4)

**Merged pull requests:**

- SkillApi docs and tests [\#174](https://github.com/OpenVoiceOS/ovos-utils/pull/174) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.35a3](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.35a3) (2023-07-04)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.35a2...V0.0.35a3)

**Closed issues:**

- Non-blocking error when running on MacOS natively [\#175](https://github.com/OpenVoiceOS/ovos-utils/issues/175)

## [V0.0.35a2](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.35a2) (2023-06-28)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.35a1...V0.0.35a2)

**Merged pull requests:**

- hotfix/missing\_value\_qml\_upload [\#173](https://github.com/OpenVoiceOS/ovos-utils/pull/173) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.35a1](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.35a1) (2023-06-21)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.34...V0.0.35a1)

**Merged pull requests:**

- Add unit tests for shutdown/restart [\#170](https://github.com/OpenVoiceOS/ovos-utils/pull/170) ([NeonDaniel](https://github.com/NeonDaniel))
- Fix dev branch coverage action [\#166](https://github.com/OpenVoiceOS/ovos-utils/pull/166) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.34](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.34) (2023-06-15)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.34a9...V0.0.34)

## [V0.0.34a9](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.34a9) (2023-06-15)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.34a8...V0.0.34a9)

**Merged pull requests:**

- Add timeout to `get_ip` to prevent tests failing on timeout [\#165](https://github.com/OpenVoiceOS/ovos-utils/pull/165) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.34a8](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.34a8) (2023-06-15)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.34a7...V0.0.34a8)

**Merged pull requests:**

- Cleanup deprecation logs [\#164](https://github.com/OpenVoiceOS/ovos-utils/pull/164) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.34a7](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.34a7) (2023-06-14)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.34a6...V0.0.34a7)

**Merged pull requests:**

- Add options to deprecation logging to configure logged caller [\#163](https://github.com/OpenVoiceOS/ovos-utils/pull/163) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.34a6](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.34a6) (2023-06-14)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.34a5...V0.0.34a6)

**Fixed bugs:**

- Fix compat. with `pages2uri` extra\_directories [\#162](https://github.com/OpenVoiceOS/ovos-utils/pull/162) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.34a5](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.34a5) (2023-06-13)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.34a3...V0.0.34a5)

**Implemented enhancements:**

- Add deprecation log helpers [\#161](https://github.com/OpenVoiceOS/ovos-utils/pull/161) ([NeonDaniel](https://github.com/NeonDaniel))
- bus upload qml [\#140](https://github.com/OpenVoiceOS/ovos-utils/pull/140) ([JarbasAl](https://github.com/JarbasAl))

**Fixed bugs:**

- Codecov automation [\#159](https://github.com/OpenVoiceOS/ovos-utils/pull/159) ([NeonDaniel](https://github.com/NeonDaniel))

**Merged pull requests:**

- Fix codecov automation [\#160](https://github.com/OpenVoiceOS/ovos-utils/pull/160) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.34a3](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.34a3) (2023-06-09)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.34a2...V0.0.34a3)

**Fixed bugs:**

- Annotate GUI Module and refactor resource resolution [\#158](https://github.com/OpenVoiceOS/ovos-utils/pull/158) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.34a2](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.34a2) (2023-06-08)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.34a1...V0.0.34a2)

**Merged pull requests:**

- Troubleshooting GUI shell plugin resource file resolution [\#157](https://github.com/OpenVoiceOS/ovos-utils/pull/157) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.34a1](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.34a1) (2023-06-08)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.33...V0.0.34a1)

**Fixed bugs:**

- Event Scheduler Interface tests [\#156](https://github.com/OpenVoiceOS/ovos-utils/pull/156) ([NeonDaniel](https://github.com/NeonDaniel))

**Merged pull requests:**

- Add unit test coverage for SkillApi [\#145](https://github.com/OpenVoiceOS/ovos-utils/pull/145) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.33](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.33) (2023-06-02)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.33a12...V0.0.33)

## [V0.0.33a12](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.33a12) (2023-05-31)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.33a11...V0.0.33a12)

**Merged pull requests:**

- Update docstrings for FileWatcher class and add unit test coverage [\#152](https://github.com/OpenVoiceOS/ovos-utils/pull/152) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.33a11](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.33a11) (2023-05-30)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.33a10...V0.0.33a11)

**Merged pull requests:**

- loosen pexpect requirement [\#153](https://github.com/OpenVoiceOS/ovos-utils/pull/153) ([mikejgray](https://github.com/mikejgray))

## [V0.0.33a10](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.33a10) (2023-05-29)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.33a9...V0.0.33a10)

**Fixed bugs:**

- fix/filewatcher [\#148](https://github.com/OpenVoiceOS/ovos-utils/pull/148) ([JarbasAl](https://github.com/JarbasAl))

**Closed issues:**

- OVOS-Cookbook link goes nowhere useful [\#150](https://github.com/OpenVoiceOS/ovos-utils/issues/150)

## [V0.0.33a9](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.33a9) (2023-05-24)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.33a8...V0.0.33a9)

**Implemented enhancements:**

- Enable Log name and level overrides from envvars [\#147](https://github.com/OpenVoiceOS/ovos-utils/pull/147) ([NeonDaniel](https://github.com/NeonDaniel))

**Closed issues:**

- os.env [\#146](https://github.com/OpenVoiceOS/ovos-utils/issues/146)
- These lines are always showing even if log\_level is set to INFO [\#142](https://github.com/OpenVoiceOS/ovos-utils/issues/142)

## [V0.0.33a8](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.33a8) (2023-05-17)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.33a7...V0.0.33a8)

**Merged pull requests:**

- Add logging to diagnose process lifecycle [\#144](https://github.com/OpenVoiceOS/ovos-utils/pull/144) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.33a7](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.33a7) (2023-05-17)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.33a6...V0.0.33a7)

**Fixed bugs:**

- Configurable skills base directory [\#143](https://github.com/OpenVoiceOS/ovos-utils/pull/143) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.33a6](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.33a6) (2023-05-04)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.33a5...V0.0.33a6)

**Implemented enhancements:**

- port LF time utils [\#141](https://github.com/OpenVoiceOS/ovos-utils/pull/141) ([emphasize](https://github.com/emphasize))

## [V0.0.33a5](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.33a5) (2023-05-01)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.33a4...V0.0.33a5)

**Implemented enhancements:**

- feat/skill\_api [\#139](https://github.com/OpenVoiceOS/ovos-utils/pull/139) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.33a4](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.33a4) (2023-05-01)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.33a3...V0.0.33a4)

**Fixed bugs:**

- fix/new\_bug [\#138](https://github.com/OpenVoiceOS/ovos-utils/pull/138) ([JarbasAl](https://github.com/JarbasAl))

**Closed issues:**

- Moving ovos-bus-client to requirements.txt? [\#137](https://github.com/OpenVoiceOS/ovos-utils/issues/137)

**Merged pull requests:**

- codecov [\#136](https://github.com/OpenVoiceOS/ovos-utils/pull/136) ([JarbasAl](https://github.com/JarbasAl))
- codecov automation [\#135](https://github.com/OpenVoiceOS/ovos-utils/pull/135) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.33a3](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.33a3) (2023-04-29)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.33a2...V0.0.33a3)

**Fixed bugs:**

- fix/core\_root\_location [\#134](https://github.com/OpenVoiceOS/ovos-utils/pull/134) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.33a2](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.33a2) (2023-04-24)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.33a1...V0.0.33a2)

## [V0.0.33a1](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.33a1) (2023-04-24)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.32...V0.0.33a1)

**Implemented enhancements:**

- feat/padatious\_samples\_in\_bus [\#133](https://github.com/OpenVoiceOS/ovos-utils/pull/133) ([JarbasAl](https://github.com/JarbasAl))

**Merged pull requests:**

- Enable release action [\#131](https://github.com/OpenVoiceOS/ovos-utils/pull/131) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.32](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.32) (2023-04-18)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.31a18...V0.0.32)

## [V0.0.31a18](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.31a18) (2023-04-18)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.31a17...V0.0.31a18)

## [V0.0.31a17](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.31a17) (2023-04-17)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.31a16...V0.0.31a17)

**Merged pull requests:**

- Update release automation [\#126](https://github.com/OpenVoiceOS/ovos-utils/pull/126) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.31a16](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.31a16) (2023-04-14)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.31a15...V0.0.31a16)

**Implemented enhancements:**

- Update `wait_for_exit_signal` to use Event.wait instead of looped sleep [\#128](https://github.com/OpenVoiceOS/ovos-utils/pull/128) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.31a15](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.31a15) (2023-04-14)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.31a14...V0.0.31a15)

**Closed issues:**

- Is there an option to disable the log file creation [\#124](https://github.com/OpenVoiceOS/ovos-utils/issues/124)

**Merged pull requests:**

- Stable extra dependencies [\#127](https://github.com/OpenVoiceOS/ovos-utils/pull/127) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.31a14](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.31a14) (2023-04-13)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.31a13...V0.0.31a14)

**Merged pull requests:**

- Update docstrings, annotate deprecation, and outline unit tests [\#119](https://github.com/OpenVoiceOS/ovos-utils/pull/119) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.31a13](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.31a13) (2023-04-13)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.31a12...V0.0.31a13)

**Fixed bugs:**

- \[log\] Only creates directory if not stdout [\#125](https://github.com/OpenVoiceOS/ovos-utils/pull/125) ([goldyfruit](https://github.com/goldyfruit))

## [V0.0.31a12](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.31a12) (2023-04-12)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.31a11...V0.0.31a12)

**Merged pull requests:**

- feat/native\_OCP [\#120](https://github.com/OpenVoiceOS/ovos-utils/pull/120) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.31a11](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.31a11) (2023-04-11)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.31a10...V0.0.31a11)

**Merged pull requests:**

- Deprecate internal `ovos_config.config` references [\#122](https://github.com/OpenVoiceOS/ovos-utils/pull/122) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.31a10](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.31a10) (2023-04-11)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.31a9...V0.0.31a10)

**Fixed bugs:**

- fix/bus compat [\#121](https://github.com/OpenVoiceOS/ovos-utils/pull/121) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.31a9](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.31a9) (2023-04-11)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.31a8...V0.0.31a9)

**Fixed bugs:**

- add back wrapper around removed methods [\#118](https://github.com/OpenVoiceOS/ovos-utils/pull/118) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.31a8](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.31a8) (2023-04-11)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.31a7...V0.0.31a8)

**Merged pull requests:**

- Update input device checks [\#81](https://github.com/OpenVoiceOS/ovos-utils/pull/81) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.31a7](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.31a7) (2023-04-10)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.31a6...V0.0.31a7)

**Merged pull requests:**

- feat/PKGBUILD [\#116](https://github.com/OpenVoiceOS/ovos-utils/pull/116) ([JarbasAl](https://github.com/JarbasAl))
- Feat/optional ovos config [\#106](https://github.com/OpenVoiceOS/ovos-utils/pull/106) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.31a6](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.31a6) (2023-04-07)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.31a5...V0.0.31a6)

**Fixed bugs:**

- fix/missing\_dependency [\#115](https://github.com/OpenVoiceOS/ovos-utils/pull/115) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.31a5](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.31a5) (2023-04-07)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.31a4...V0.0.31a5)

**Fixed bugs:**

- fix/missing\_dependency [\#114](https://github.com/OpenVoiceOS/ovos-utils/pull/114) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.31a4](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.31a4) (2023-04-06)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.31a3...V0.0.31a4)

**Merged pull requests:**

- Update rapidfuzz dependency [\#112](https://github.com/OpenVoiceOS/ovos-utils/pull/112) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.31a3](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.31a3) (2023-04-05)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.31a2...V0.0.31a3)

**Merged pull requests:**

- feat/FakeMessage [\#111](https://github.com/OpenVoiceOS/ovos-utils/pull/111) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.31a2](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.31a2) (2023-04-05)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.31a1...V0.0.31a2)

**Merged pull requests:**

- refactor/ovos-bus-client [\#110](https://github.com/OpenVoiceOS/ovos-utils/pull/110) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.31a1](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.31a1) (2023-03-23)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.30...V0.0.31a1)

**Merged pull requests:**

- Add show input box method for skills [\#109](https://github.com/OpenVoiceOS/ovos-utils/pull/109) ([AIIX](https://github.com/AIIX))

## [V0.0.30](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.30) (2023-03-09)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.30a4...V0.0.30)

## [V0.0.30a4](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.30a4) (2023-03-09)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.30a3...V0.0.30a4)

**Merged pull requests:**

- Update dependencies to stable versions [\#107](https://github.com/OpenVoiceOS/ovos-utils/pull/107) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.30a3](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.30a3) (2023-03-08)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.30a2...V0.0.30a3)

**Merged pull requests:**

- Bump ovos-config dependency cleanup module init [\#104](https://github.com/OpenVoiceOS/ovos-utils/pull/104) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.30a2](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.30a2) (2023-03-08)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.30a1...V0.0.30a2)

**Implemented enhancements:**

- feat/console\_scripts [\#105](https://github.com/OpenVoiceOS/ovos-utils/pull/105) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.30a1](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.30a1) (2023-03-08)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.29...V0.0.30a1)

**Merged pull requests:**

- Implement module\_property decorator with unit test [\#103](https://github.com/OpenVoiceOS/ovos-utils/pull/103) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.29](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.29) (2023-03-03)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.29a2...V0.0.29)

## [V0.0.29a2](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.29a2) (2023-03-03)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.29a1...V0.0.29a2)

**Fixed bugs:**

- fix/circular\_import [\#101](https://github.com/OpenVoiceOS/ovos-utils/pull/101) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.29a1](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.29a1) (2023-03-03)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.28...V0.0.29a1)

**Implemented enhancements:**

- Migrate/lock monotonic event [\#100](https://github.com/OpenVoiceOS/ovos-utils/pull/100) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.28](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.28) (2023-02-24)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.28a7...V0.0.28)

## [V0.0.28a7](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.28a7) (2023-02-16)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.28a6...V0.0.28a7)

**Merged pull requests:**

- Refactor SSH helpers and add generic systemd helpers [\#95](https://github.com/OpenVoiceOS/ovos-utils/pull/95) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.28a6](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.28a6) (2023-02-15)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.28a5...V0.0.28a6)

**Merged pull requests:**

- Handle default network config values if core configuration is incomplete [\#99](https://github.com/OpenVoiceOS/ovos-utils/pull/99) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.28a5](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.28a5) (2023-02-15)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.28a4...V0.0.28a5)

**Implemented enhancements:**

- port network utils from mk2 [\#85](https://github.com/OpenVoiceOS/ovos-utils/issues/85)
- improve network checks [\#88](https://github.com/OpenVoiceOS/ovos-utils/pull/88) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.28a4](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.28a4) (2023-02-08)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.28a3...V0.0.28a4)

**Implemented enhancements:**

- minor utils fix [\#98](https://github.com/OpenVoiceOS/ovos-utils/pull/98) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.28a3](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.28a3) (2023-02-07)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.28a2...V0.0.28a3)

**Implemented enhancements:**

- feat/runtime\_requirements gui [\#97](https://github.com/OpenVoiceOS/ovos-utils/pull/97) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.28a2](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.28a2) (2023-02-04)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.28a1...V0.0.28a2)

**Implemented enhancements:**

- feat/network\_reqs\_from\_workshop [\#96](https://github.com/OpenVoiceOS/ovos-utils/pull/96) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.28a1](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.28a1) (2023-01-25)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.27...V0.0.28a1)

**Fixed bugs:**

- According to the usage, you should be able to pass the name to LOG\(\). [\#94](https://github.com/OpenVoiceOS/ovos-utils/pull/94) ([gmsoft-tuxicoman](https://github.com/gmsoft-tuxicoman))

## [V0.0.27](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.27) (2023-01-20)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.27a8...V0.0.27)

## [V0.0.27a8](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.27a8) (2023-01-20)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.27a7...V0.0.27a8)

**Merged pull requests:**

- Log deprecation warning in `layers` module [\#93](https://github.com/OpenVoiceOS/ovos-utils/pull/93) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.27a7](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.27a7) (2023-01-12)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.27a6...V0.0.27a7)

**Merged pull requests:**

- add transient duration config [\#92](https://github.com/OpenVoiceOS/ovos-utils/pull/92) ([emphasize](https://github.com/emphasize))

## [V0.0.27a6](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.27a6) (2023-01-05)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.27a5...V0.0.27a6)

**Fixed bugs:**

- fix/mouse\_detect\_again [\#90](https://github.com/OpenVoiceOS/ovos-utils/pull/90) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.27a5](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.27a5) (2022-12-16)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.27a4...V0.0.27a5)

**Implemented enhancements:**

- sync utils with core [\#89](https://github.com/OpenVoiceOS/ovos-utils/pull/89) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.27a4](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.27a4) (2022-11-30)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.27a3...V0.0.27a4)

**Merged pull requests:**

- Add background\_color to show image and show animated image [\#86](https://github.com/OpenVoiceOS/ovos-utils/pull/86) ([AIIX](https://github.com/AIIX))

## [V0.0.27a3](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.27a3) (2022-11-15)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.27a2...V0.0.27a3)

**Merged pull requests:**

- gui notification callback data [\#84](https://github.com/OpenVoiceOS/ovos-utils/pull/84) ([AIIX](https://github.com/AIIX))

## [V0.0.27a2](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.27a2) (2022-11-11)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.27a1...V0.0.27a2)

**Fixed bugs:**

- fix sudo flag again [\#83](https://github.com/OpenVoiceOS/ovos-utils/pull/83) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.27a1](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.27a1) (2022-11-11)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.26...V0.0.27a1)

**Fixed bugs:**

- fix sudo flag [\#82](https://github.com/OpenVoiceOS/ovos-utils/pull/82) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.26](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.26) (2022-10-29)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.26a2...V0.0.26)

## [V0.0.26a2](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.26a2) (2022-10-22)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.26a1...V0.0.26a2)

**Implemented enhancements:**

- refactor some stuff to properties for better compatibility with ovos-… [\#80](https://github.com/OpenVoiceOS/ovos-utils/pull/80) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.26a1](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.26a1) (2022-10-19)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.25...V0.0.26a1)

**Implemented enhancements:**

- feat/event\_wrappers\_in\_outils [\#79](https://github.com/OpenVoiceOS/ovos-utils/pull/79) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.25](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.25) (2022-10-18)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.25a15...V0.0.25)

**Merged pull requests:**

- license + vulnerability tests [\#78](https://github.com/OpenVoiceOS/ovos-utils/pull/78) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.25a15](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.25a15) (2022-10-18)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.25a14...V0.0.25a15)

**Fixed bugs:**

- fix input detect again [\#77](https://github.com/OpenVoiceOS/ovos-utils/pull/77) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.25a14](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.25a14) (2022-10-17)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.25a13...V0.0.25a14)

**Fixed bugs:**

- fallback to True for mouse detection if libinput is missing [\#76](https://github.com/OpenVoiceOS/ovos-utils/pull/76) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.25a13](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.25a13) (2022-10-17)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.25a12...V0.0.25a13)

**Implemented enhancements:**

- scan /dev/input for device detection [\#75](https://github.com/OpenVoiceOS/ovos-utils/pull/75) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.25a12](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.25a12) (2022-10-17)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.25a11...V0.0.25a12)

**Fixed bugs:**

- feat/xinput support [\#74](https://github.com/OpenVoiceOS/ovos-utils/pull/74) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.25a11](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.25a11) (2022-10-11)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.25a10...V0.0.25a11)

**Merged pull requests:**

- add mail api point to ovos api service [\#73](https://github.com/OpenVoiceOS/ovos-utils/pull/73) ([AIIX](https://github.com/AIIX))

## [V0.0.25a10](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.25a10) (2022-10-10)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.25a9...V0.0.25a10)

**Closed issues:**

- `get_mycroft_bus` ignores Configuration [\#71](https://github.com/OpenVoiceOS/ovos-utils/issues/71)

**Merged pull requests:**

- Update `ovos_config` references, Read config in `get_mycroft_bus` [\#72](https://github.com/OpenVoiceOS/ovos-utils/pull/72) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.25a9](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.25a9) (2022-10-10)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.25a8...V0.0.25a9)

**Fixed bugs:**

- remove "logs" subfolder [\#70](https://github.com/OpenVoiceOS/ovos-utils/pull/70) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.25a8](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.25a8) (2022-10-07)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.25a7...V0.0.25a8)

**Implemented enhancements:**

- Update log.py [\#69](https://github.com/OpenVoiceOS/ovos-utils/pull/69) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.25a7](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.25a7) (2022-10-03)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.25a6...V0.0.25a7)

**Implemented enhancements:**

- feat/email\_utils [\#68](https://github.com/OpenVoiceOS/ovos-utils/pull/68) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.25a6](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.25a6) (2022-09-28)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.25a5...V0.0.25a6)

**Merged pull requests:**

- Add geolocate methods support in ovos\_api\_service [\#67](https://github.com/OpenVoiceOS/ovos-utils/pull/67) ([AIIX](https://github.com/AIIX))

## [V0.0.25a5](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.25a5) (2022-09-16)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.25a4...V0.0.25a5)

**Implemented enhancements:**

- Add methods for controlled notifications [\#66](https://github.com/OpenVoiceOS/ovos-utils/pull/66) ([AIIX](https://github.com/AIIX))

## [V0.0.25a4](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.25a4) (2022-09-10)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.25a3...V0.0.25a4)

**Implemented enhancements:**

- feat/timed\_lru\_cache [\#65](https://github.com/OpenVoiceOS/ovos-utils/pull/65) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.25a3](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.25a3) (2022-09-10)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.25a2...V0.0.25a3)

**Fixed bugs:**

- fix/syntax\_error [\#64](https://github.com/OpenVoiceOS/ovos-utils/pull/64) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.25a2](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.25a2) (2022-09-08)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.25a1...V0.0.25a2)

**Merged pull requests:**

- Add method to restart arbitrary systemd service [\#63](https://github.com/OpenVoiceOS/ovos-utils/pull/63) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.25a1](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.25a1) (2022-09-07)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.24...V0.0.25a1)

**Implemented enhancements:**

- add more api methods [\#62](https://github.com/OpenVoiceOS/ovos-utils/pull/62) ([AIIX](https://github.com/AIIX))

## [V0.0.24](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.24) (2022-09-07)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.24a4...V0.0.24)

## [V0.0.24a4](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.24a4) (2022-09-06)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.24a3...V0.0.24a4)

**Merged pull requests:**

- add systemctl mycroft restart option [\#61](https://github.com/OpenVoiceOS/ovos-utils/pull/61) ([AIIX](https://github.com/AIIX))

## [V0.0.24a3](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.24a3) (2022-09-06)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.24a2...V0.0.24a3)

**Implemented enhancements:**

- feat/ovos\_api [\#60](https://github.com/OpenVoiceOS/ovos-utils/pull/60) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.24a2](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.24a2) (2022-08-17)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.24a1...V0.0.24a2)

**Merged pull requests:**

- Handle exceptions getting cache directory when MemoryTempfile fails \(i.e. in a chroot\) [\#58](https://github.com/OpenVoiceOS/ovos-utils/pull/58) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.24a1](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.24a1) (2022-08-15)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.23...V0.0.24a1)

**Merged pull requests:**

- Add extend about data method to gui utils [\#57](https://github.com/OpenVoiceOS/ovos-utils/pull/57) ([AIIX](https://github.com/AIIX))

## [V0.0.23](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.23) (2022-07-20)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.23a7...V0.0.23)

## [V0.0.23a7](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.23a7) (2022-07-20)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.23a6...V0.0.23a7)

**Implemented enhancements:**

- Skill location utilities [\#55](https://github.com/OpenVoiceOS/ovos-utils/pull/55) ([NeonDaniel](https://github.com/NeonDaniel))

**Merged pull requests:**

- Update release tag workflows to include version change commits [\#56](https://github.com/OpenVoiceOS/ovos-utils/pull/56) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.23a6](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.23a6) (2022-07-06)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.23a5...V0.0.23a6)

**Merged pull requests:**

- refactor/use ovos\_config package [\#52](https://github.com/OpenVoiceOS/ovos-utils/pull/52) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.23a5](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.23a5) (2022-07-06)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.23a4...V0.0.23a5)

**Implemented enhancements:**

- port/file\_watcher [\#54](https://github.com/OpenVoiceOS/ovos-utils/pull/54) ([NeonJarbas](https://github.com/NeonJarbas))

## [V0.0.23a4](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.23a4) (2022-07-06)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.23a3...V0.0.23a4)

**Merged pull requests:**

- Loosen mycroft-messagebus-client dependency to allow 0.10.0 [\#53](https://github.com/OpenVoiceOS/ovos-utils/pull/53) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.23a3](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.23a3) (2022-06-15)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.23a2...V0.0.23a3)

**Fixed bugs:**

- Prevent raising exception when msm config not present [\#51](https://github.com/OpenVoiceOS/ovos-utils/pull/51) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.23a2](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.23a2) (2022-06-10)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.23a1...V0.0.23a2)

**Fixed bugs:**

- fix/allow\_LF\_lang\_to\_be\_None [\#50](https://github.com/OpenVoiceOS/ovos-utils/pull/50) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.23a1](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.23a1) (2022-06-07)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.22...V0.0.23a1)

**Fixed bugs:**

- fix/screen\_check [\#49](https://github.com/OpenVoiceOS/ovos-utils/pull/49) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.22](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.22) (2022-06-02)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.22a3...V0.0.22)

## [V0.0.22a3](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.22a3) (2022-06-02)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.22a2...V0.0.22a3)

**Fixed bugs:**

- Fix/full lang [\#48](https://github.com/OpenVoiceOS/ovos-utils/pull/48) ([NeonJarbas](https://github.com/NeonJarbas))

## [V0.0.22a2](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.22a2) (2022-05-31)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.22a1...V0.0.22a2)

**Implemented enhancements:**

- feat/lang\_utils [\#47](https://github.com/OpenVoiceOS/ovos-utils/pull/47) ([NeonJarbas](https://github.com/NeonJarbas))

## [V0.0.22a1](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.22a1) (2022-05-17)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.21...V0.0.22a1)

**Implemented enhancements:**

- support ovos-shell [\#45](https://github.com/OpenVoiceOS/ovos-utils/pull/45) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.21](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.21) (2022-05-17)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.21a6...V0.0.21)

## [V0.0.21a6](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.21a6) (2022-05-17)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.21a5...V0.0.21a6)

**Implemented enhancements:**

- add InputDeviceHelper to detect available inputs on current system [\#44](https://github.com/OpenVoiceOS/ovos-utils/pull/44) ([AIIX](https://github.com/AIIX))

## [V0.0.21a5](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.21a5) (2022-05-12)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.21a4...V0.0.21a5)

**Implemented enhancements:**

- Add widgets helper [\#43](https://github.com/OpenVoiceOS/ovos-utils/pull/43) ([AIIX](https://github.com/AIIX))

## [V0.0.21a4](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.21a4) (2022-05-09)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.21a3...V0.0.21a4)

**Merged pull requests:**

- refactor/migrate\_adapt\_boilerplate [\#42](https://github.com/OpenVoiceOS/ovos-utils/pull/42) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.21a3](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.21a3) (2022-05-07)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.21a2...V0.0.21a3)

**Merged pull requests:**

- add sdist [\#41](https://github.com/OpenVoiceOS/ovos-utils/pull/41) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.21a2](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.21a2) (2022-05-07)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.21a1...V0.0.21a2)

**Merged pull requests:**

- Fix/remove unused dep [\#40](https://github.com/OpenVoiceOS/ovos-utils/pull/40) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.21a1](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.21a1) (2022-05-07)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.20...V0.0.21a1)

**Fixed bugs:**

- Fix/adapt [\#39](https://github.com/OpenVoiceOS/ovos-utils/pull/39) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.20](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.20) (2022-04-27)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.20a4...V0.0.20)

## [V0.0.20a4](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.20a4) (2022-04-27)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.20a3...V0.0.20a4)

**Implemented enhancements:**

- Adds ovos service api [\#38](https://github.com/OpenVoiceOS/ovos-utils/pull/38) ([AIIX](https://github.com/AIIX))

**Merged pull requests:**

- notify matrix chat on PR merged [\#37](https://github.com/OpenVoiceOS/ovos-utils/pull/37) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.20a3](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.20a3) (2022-03-23)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.20a2...V0.0.20a3)

**Implemented enhancements:**

- Feat/list utils [\#36](https://github.com/OpenVoiceOS/ovos-utils/pull/36) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.20a2](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.20a2) (2022-03-16)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.20a1...V0.0.20a2)

**Implemented enhancements:**

- Feat/process utils [\#35](https://github.com/OpenVoiceOS/ovos-utils/pull/35) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.20a1](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.20a1) (2022-03-03)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.19...V0.0.20a1)

**Fixed bugs:**

- Fix/resolve resource file [\#34](https://github.com/OpenVoiceOS/ovos-utils/pull/34) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.19](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.19) (2022-03-03)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.19a3...V0.0.19)

## [V0.0.19a3](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.19a3) (2022-03-03)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.19a2...V0.0.19a3)

**Fixed bugs:**

- fix/platform\_detect [\#33](https://github.com/OpenVoiceOS/ovos-utils/pull/33) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.19a2](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.19a2) (2022-03-03)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.17a6...V0.0.19a2)

**Breaking changes:**

- Refactor/remove deprecated [\#11](https://github.com/OpenVoiceOS/ovos-utils/pull/11) ([JarbasAl](https://github.com/JarbasAl))

**Merged pull requests:**

- Fix/package workflow [\#32](https://github.com/OpenVoiceOS/ovos-utils/pull/32) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.17a6](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.17a6) (2022-02-25)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.17a5...V0.0.17a6)

**Fixed bugs:**

- Handle stopwatch.stop before started [\#31](https://github.com/OpenVoiceOS/ovos-utils/pull/31) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.17a5](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.17a5) (2022-02-25)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.18...V0.0.17a5)

**Merged pull requests:**

- Refactor/workflows from template [\#30](https://github.com/OpenVoiceOS/ovos-utils/pull/30) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.18](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.18) (2022-02-24)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/V0.0.17a4...V0.0.18)

## [V0.0.17a4](https://github.com/OpenVoiceOS/ovos-utils/tree/V0.0.17a4) (2022-02-24)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/0.0.12...V0.0.17a4)

**Implemented enhancements:**

- Feat/diagnostic mode [\#18](https://github.com/OpenVoiceOS/ovos-utils/pull/18) ([NeonJarbas](https://github.com/NeonJarbas))
- fix/play\_audio [\#14](https://github.com/OpenVoiceOS/ovos-utils/pull/14) ([NeonJarbas](https://github.com/NeonJarbas))
- Feat/better stop watch [\#10](https://github.com/OpenVoiceOS/ovos-utils/pull/10) ([JarbasAl](https://github.com/JarbasAl))
- Feat/more file utils [\#9](https://github.com/OpenVoiceOS/ovos-utils/pull/9) ([JarbasAl](https://github.com/JarbasAl))
- add notification api change and style parameter [\#6](https://github.com/OpenVoiceOS/ovos-utils/pull/6) ([AIIX](https://github.com/AIIX))

**Fixed bugs:**

- Fix/core module detection + refactor xdg config path utils [\#28](https://github.com/OpenVoiceOS/ovos-utils/pull/28) ([NeonJarbas](https://github.com/NeonJarbas))
- Fix typo in configuration paths [\#27](https://github.com/OpenVoiceOS/ovos-utils/pull/27) ([NeonDaniel](https://github.com/NeonDaniel))
- Add back colour dependency [\#24](https://github.com/OpenVoiceOS/ovos-utils/pull/24) ([NeonDaniel](https://github.com/NeonDaniel))
- Add user config home to `get_xdg_config_dirs` [\#23](https://github.com/OpenVoiceOS/ovos-utils/pull/23) ([NeonDaniel](https://github.com/NeonDaniel))
- Loosen dependency versions for OVOS image compat [\#16](https://github.com/OpenVoiceOS/ovos-utils/pull/16) ([NeonDaniel](https://github.com/NeonDaniel))
- Ovos conf [\#12](https://github.com/OpenVoiceOS/ovos-utils/pull/12) ([NeonJarbas](https://github.com/NeonJarbas))
- fix/update\_enclosure\_api [\#8](https://github.com/OpenVoiceOS/ovos-utils/pull/8) ([JarbasAl](https://github.com/JarbasAl))
- Fix/nested delete [\#7](https://github.com/OpenVoiceOS/ovos-utils/pull/7) ([JarbasAl](https://github.com/JarbasAl))

**Closed issues:**

- Dependency Version specs [\#13](https://github.com/OpenVoiceOS/ovos-utils/issues/13)
- dependencies are duplicated  + add version specs  [\#5](https://github.com/OpenVoiceOS/ovos-utils/issues/5)

**Merged pull requests:**

- feat/packaging workflows [\#29](https://github.com/OpenVoiceOS/ovos-utils/pull/29) ([JarbasAl](https://github.com/JarbasAl))
- Update license\_tests.yml [\#26](https://github.com/OpenVoiceOS/ovos-utils/pull/26) ([NeonJarbas](https://github.com/NeonJarbas))
- Feat/pypi workflow [\#25](https://github.com/OpenVoiceOS/ovos-utils/pull/25) ([NeonJarbas](https://github.com/NeonJarbas))
- feat/license tests workflow [\#22](https://github.com/OpenVoiceOS/ovos-utils/pull/22) ([JarbasAl](https://github.com/JarbasAl))
- refactor/replace\_pyxdg [\#21](https://github.com/OpenVoiceOS/ovos-utils/pull/21) ([NeonJarbas](https://github.com/NeonJarbas))
- refactor/bump\_requests [\#20](https://github.com/OpenVoiceOS/ovos-utils/pull/20) ([NeonJarbas](https://github.com/NeonJarbas))
- refactor/deprecate\_inflection [\#19](https://github.com/OpenVoiceOS/ovos-utils/pull/19) ([NeonJarbas](https://github.com/NeonJarbas))
- Refactor requirements to read from files [\#15](https://github.com/OpenVoiceOS/ovos-utils/pull/15) ([NeonDaniel](https://github.com/NeonDaniel))

## [0.0.12](https://github.com/OpenVoiceOS/ovos-utils/tree/0.0.12) (2021-11-04)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/25fe462e3c19a58f32dc1fd940bf7c96fc18e6de...0.0.12)

**Implemented enhancements:**

- release0.0.12/extract get\_local\_settings and save\_settings from core [\#4](https://github.com/OpenVoiceOS/ovos-utils/pull/4) ([JarbasAl](https://github.com/JarbasAl))
- Adds checked path to log that root config path was not found [\#3](https://github.com/OpenVoiceOS/ovos-utils/pull/3) ([NeonDaniel](https://github.com/NeonDaniel))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
